<?php

if (!defined("ABSPATH")) {
    exit();
}

class wpDiscuzHDCOptions {

    public $settingsOptionName = "wpdiscuz_hdc_options";
    public $tabKey = "hdc";
    public $buttonText;

    public function __construct() {
        add_action("wpdiscuz_save_options", [&$this, "saveOptions"], 13);
        add_action("wpdiscuz_reset_options", [&$this, "resetOptions"], 13);
        add_filter("wpdiscuz_settings", [&$this, "settingsArray"], 75);
        $this->init();
    }

    public function init() {
        $this->addOptions();
        $this->initOptions(get_option($this->settingsOptionName));
    }

    public function addOptions() {
        add_option($this->settingsOptionName, $this->defaultOptions(), "", "no");
    }

    public function initOptions($options) {
        $defaults = $this->defaultOptions();
        $this->buttonText = isset($options["buttonText"]) ? $options["buttonText"] : $defaults["buttonText"];
    }

    public function saveOptions() {
        if ($this->tabKey === $_POST["wpd_tab"]) {
            $this->buttonText = isset($_POST[$this->tabKey]["buttonText"]) ? sanitize_text_field($_POST[$this->tabKey]["buttonText"])  : '';
            update_option($this->settingsOptionName, $this->toArray());
        }
    }

    public function resetOptions($tab) {
        if ($tab === $this->tabKey || $tab === "all") {
            update_option($this->settingsOptionName, $this->defaultOptions());
            $this->initOptions(get_option($this->settingsOptionName));
        }
    }

    public function defaultOptions() {
        return [
            "buttonText" => 'Join the Conversation',
        ];
    }

    public function toArray() {
        return [
            "buttonText" => $this->buttonText
        ];
    }

    public function settingsArray($settings) {
        $settings["addons"][$this->tabKey] = [
            "title" => __("Hidden Comments", "wpdiscuz_hdc"),
            "title_original" => "Hidden Comments",
            "icon" => "",
            "icon-height" => "",
            "file_path" => WPDHDC_DIR_PATH . "/options/html-options.php",
            "values" => $this,
            "options" => [
                "buttonText" => [
                    "label" => __("Button Text", "wpdiscuz_hdc"),
                    "label_original" => "Button Text",
                    "description" => "",
                    "description_original" => "",
                    "docurl" => "",
                ],
            ],
        ];
        return $settings;
    }

}
